"use strict";

require("reflect-metadata");
require("express-async-errors");
var _express = _interopRequireDefault(require("express"));
var _cors = _interopRequireDefault(require("cors"));
var _index = require("./typeorm/index");
var _AppError = _interopRequireDefault(require("./errors/AppError"));
var _dotenv = _interopRequireDefault(require("dotenv"));
var _index2 = require("./routes/index.routes");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/* eslint-disable @typescript-eslint/no-unused-vars */

_dotenv.default.config();
_index.AppDataSource.initialize().then(() => {
  const app = (0, _express.default)();
  app.use((req, res, next) => {
    // Qual site tem permissão de realizar a conexão, no exemplo abaixo está o "*" indicando que qualquer site pode fazer a conexão
    res.header('Access-Control-Allow-Origin', '*');
    // Quais são os métodos que a conexão pode realizar na API
    res.header('Access-Control-Allow-Methods', 'GET,PUT,POST,DELETE');
    app.use((0, _cors.default)());
    next();
  });
  app.use(_express.default.json());
  app.use((error, req, res, next) => {
    if (error instanceof _AppError.default) {
      return res.status(error.statusCode).json(error.message);
    }
    return res.status(500).json({
      status: 'error',
      message: 'Internal server'
    });
  });
  app.get('/', (_req, res) => {
    res.json({
      Teste: 'teste'
    });
  });
  app.use('', _index2.router);
  const port = process.env.PORT;
  app.listen(port, () => {
    console.log(`RODANDO NA PORTA ${port}`);
  });
});